=======================
Configuration Reference
=======================

Many aspects of the Bare Metal service are specific to the environment
it is deployed in. The following pages describe configuration
options that can be used to adjust the service to your particular
situation.

.. toctree::
  :maxdepth: 1

  Configuration Options <config>
  Policies <policy>

.. only:: html

   Sample files
   ------------

   .. toctree::
      :maxdepth: 1

      Sample Config File <sample-config>
      Sample Policy File <sample-policy>
